==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/state/grouping/NxmNxCtStateBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.state.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxmNxCtStateBuilder} instances.
 *
 * @see NxmNxCtStateBuilder
 *
 */
public class NxmNxCtStateBuilder implements Builder<NxmNxCtState> {

    private Long _ctState;
    private Long _mask;


    Map<Class<? extends Augmentation<NxmNxCtState>>, Augmentation<NxmNxCtState>> augmentation = Collections.emptyMap();

    public NxmNxCtStateBuilder() {
    }

    public NxmNxCtStateBuilder(NxmNxCtState base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmNxCtState>>, Augmentation<NxmNxCtState>> aug =((AugmentationHolder<NxmNxCtState>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._ctState = base.getCtState();
        this._mask = base.getMask();
    }


    public Long getCtState() {
        return _ctState;
    }
    
    public Long getMask() {
        return _mask;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmNxCtState>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkCtStateRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public NxmNxCtStateBuilder setCtState(final Long value) {
    if (value != null) {
        checkCtStateRange(value);
        
    }
        this._ctState = value;
        return this;
    }
    private static void checkMaskRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public NxmNxCtStateBuilder setMask(final Long value) {
    if (value != null) {
        checkMaskRange(value);
        
    }
        this._mask = value;
        return this;
    }
    
    public NxmNxCtStateBuilder addAugmentation(Class<? extends Augmentation<NxmNxCtState>> augmentationType, Augmentation<NxmNxCtState> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmNxCtStateBuilder removeAugmentation(Class<? extends Augmentation<NxmNxCtState>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmNxCtState build() {
        return new NxmNxCtStateImpl(this);
    }

    private static final class NxmNxCtStateImpl
        extends AbstractAugmentable<NxmNxCtState>
        implements NxmNxCtState {
    
        private final Long _ctState;
        private final Long _mask;
    
        NxmNxCtStateImpl(NxmNxCtStateBuilder base) {
            super(base.augmentation);
            this._ctState = base.getCtState();
            this._mask = base.getMask();
        }
    
        @Override
        public Class<NxmNxCtState> getImplementedInterface() {
            return NxmNxCtState.class;
        }
    
        @Override
        public Long getCtState() {
            return _ctState;
        }
        
        @Override
        public Long getMask() {
            return _mask;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ctState);
            result = prime * result + Objects.hashCode(_mask);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmNxCtState.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxmNxCtState other = (NxmNxCtState)obj;
            if (!Objects.equals(_ctState, other.getCtState())) {
                return false;
            }
            if (!Objects.equals(_mask, other.getMask())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmNxCtStateImpl otherImpl = (NxmNxCtStateImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmNxCtState>>, Augmentation<NxmNxCtState>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmNxCtState");
            CodeHelpers.appendValue(helper, "_ctState", _ctState);
            CodeHelpers.appendValue(helper, "_mask", _mask);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/state/grouping/NxmNxCtStateBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.state.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxmNxCtStateBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxmNxCtStateBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxmNxCtStateBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxmNxCtStateBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxmNxCtStateBuilder
 * @see Builder
 *
 */
public class NxmNxCtStateBuilder implements Builder<NxmNxCtState> {

    private Long _ctState;
    private Long _mask;


    Map<Class<? extends Augmentation<NxmNxCtState>>, Augmentation<NxmNxCtState>> augmentation = Collections.emptyMap();

    public NxmNxCtStateBuilder() {
    }

    public NxmNxCtStateBuilder(NxmNxCtState base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmNxCtState>>, Augmentation<NxmNxCtState>> aug =((AugmentationHolder<NxmNxCtState>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._ctState = base.getCtState();
        this._mask = base.getMask();
    }


    public Long getCtState() {
        return _ctState;
    }
    
    public Long getMask() {
        return _mask;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmNxCtState>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkCtStateRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public NxmNxCtStateBuilder setCtState(final Long value) {
    if (value != null) {
        checkCtStateRange(value);
        
    }
        this._ctState = value;
        return this;
    }
    private static void checkMaskRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public NxmNxCtStateBuilder setMask(final Long value) {
    if (value != null) {
        checkMaskRange(value);
        
    }
        this._mask = value;
        return this;
    }
    
    public NxmNxCtStateBuilder addAugmentation(Class<? extends Augmentation<NxmNxCtState>> augmentationType, Augmentation<NxmNxCtState> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmNxCtStateBuilder removeAugmentation(Class<? extends Augmentation<NxmNxCtState>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmNxCtState build() {
        return new NxmNxCtStateImpl(this);
    }

    private static final class NxmNxCtStateImpl
        extends AbstractAugmentable<NxmNxCtState>
        implements NxmNxCtState {
    
        private final Long _ctState;
        private final Long _mask;
    
        NxmNxCtStateImpl(NxmNxCtStateBuilder base) {
            super(base.augmentation);
            this._ctState = base.getCtState();
            this._mask = base.getMask();
        }
    
        @Override
        public Class<NxmNxCtState> getImplementedInterface() {
            return NxmNxCtState.class;
        }
    
        @Override
        public Long getCtState() {
            return _ctState;
        }
        
        @Override
        public Long getMask() {
            return _mask;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ctState);
            result = prime * result + Objects.hashCode(_mask);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmNxCtState.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxmNxCtState other = (NxmNxCtState)obj;
            if (!Objects.equals(_ctState, other.getCtState())) {
                return false;
            }
            if (!Objects.equals(_mask, other.getMask())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmNxCtStateImpl otherImpl = (NxmNxCtStateImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmNxCtState>>, Augmentation<NxmNxCtState>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmNxCtState");
            CodeHelpers.appendValue(helper, "_ctState", _ctState);
            CodeHelpers.appendValue(helper, "_mask", _mask);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
